==> walkers-fabric-1.18.2-5.3.3-sources.jar: tocraft/walkers/ability/impl/generic/RandomTeleportationAbility.java <==
package tocraft.walkers.ability.impl.generic;

import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3532;
import tocraft.walkers.Walkers;
import tocraft.walkers.ability.GenericShapeAbility;

public class RandomTeleportationAbility<T extends class_1308> extends GenericShapeAbility<T> {
    public static final class_2960 ID = Walkers.id("random_teleportation");
    public static final MapCodec<RandomTeleportationAbility<?>> CODEC = RecordCodecBuilder.mapCodec((instance) -> instance.stable(new RandomTeleportationAbility<>()));

    @Override
    public class_2960 getId() {
        return ID;
    }

    @Override
    public MapCodec<? extends GenericShapeAbility<?>> codec() {
        return CODEC;
    }

    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        double x = player.method_23317();
        double y = player.method_23318();
        double z = player.method_23321();

        for (int i = 0; i < 16; ++i) {
            // Pick a random location nearby to teleport to.
            double g = player.method_23317() + (player.method_6051().nextDouble() - 0.5D) * 16.0D;
            double h = class_3532.method_15350(player.method_23318() + (double) (player.method_6051().nextInt(16) - 8), 0.0D, world.method_31605() - 1);
            double j = player.method_23321() + (player.method_6051().nextDouble() - 0.5D) * 16.0D;

            // Cancel vehicle/riding mechanics.
            if (player.method_5765()) {
                player.method_5848();
            }

            // Teleport the player and play sound FX if it succeeds.
            if (player.method_6082(g, h, j, true)) {
                class_3414 soundEvent = class_3417.field_14890;
                world.method_8465(null, x, y, z, soundEvent, class_3419.field_15248, 1.0F, 1.0F);
                player.method_5783(soundEvent, 1.0F, 1.0F);
                break;
            }
        }
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8233;
    }
}

==> walkers-fabric-1.19.4-5.2-sources.jar: tocraft/walkers/ability/impl/generic/RandomTeleportationAbility.java <==
package tocraft.walkers.ability.impl.generic;

import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3532;
import tocraft.walkers.Walkers;
import tocraft.walkers.ability.GenericShapeAbility;

public class RandomTeleportationAbility<T extends class_1308> extends GenericShapeAbility<T> {
    public static final class_2960 ID = Walkers.id("random_teleportation");
    public static final MapCodec<RandomTeleportationAbility<?>> CODEC = RecordCodecBuilder.mapCodec((instance) -> instance.stable(new RandomTeleportationAbility<>()));

    @Override
    public class_2960 getId() {
        return ID;
    }

    @Override
    public MapCodec<? extends GenericShapeAbility<?>> codec() {
        return CODEC;
    }

    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        double x = player.method_23317();
        double y = player.method_23318();
        double z = player.method_23321();

        for (int i = 0; i < 16; ++i) {
            // Pick a random location nearby to teleport to.
            double g = player.method_23317() + (player.method_6051().method_43058() - 0.5D) * 16.0D;
            double h = class_3532.method_15350(player.method_23318() + (double) (player.method_6051().method_43048(16) - 8), 0.0D, world.method_31605() - 1);
            double j = player.method_23321() + (player.method_6051().method_43058() - 0.5D) * 16.0D;

            // Cancel vehicle/riding mechanics.
            if (player.method_5765()) {
                player.method_5848();
            }

            // Teleport the player and play sound FX if it succeeds.
            if (player.method_6082(g, h, j, true)) {
                class_3414 soundEvent = class_3417.field_14890;
                world.method_43128(null, x, y, z, soundEvent, class_3419.field_15248, 1.0F, 1.0F);
                player.method_5783(soundEvent, 1.0F, 1.0F);
                break;
            }
        }
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8233;
    }
}
